@@ -5,9 +5,7 @@ is valid.
 All time estimates below were produced on a 2013 MacBook Pro with a
 2.8 GHz Intel Core i7 processor and 16GB of RAM running OS 10.9.2.
 """
-from __future__ import print_function, division
 import datetime as dt
-from itertools import izip
 import dateutil.relativedelta as rd
 from collections import OrderedDict
 import os
@@ -19,17 +17,22 @@ import numpy as np
 from shapely.geometry import LineString
 import utm
 
-import utils
+import gtfs_toolkit.utils as utils
 
 class Feed(object):
     """
-    A class to gather all the GTFS files for a feed and store them as 
-    Pandas data frames.
+    A class to gather all the GTFS files for a feed and store them in memory 
+    as Pandas data frames.  
+    Make sure you have enough memory!  
+    The stop times object can be big.
+    Assume the feed has a 
     """
     def __init__(self, path):
         """
         Read in all the relevant GTFS text files within the directory or 
         ZIP file given by ``path``.
+        Assume the zip file unzips as a collection of GTFS text files
+        rather than as a directory of GTFS text files.
         """
         zipped = False
         if zipfile.is_zipfile(path):
@@ -51,17 +54,15 @@ class Feed(object):
     
         # Prefix a 0 to arrival and departure times if necessary.
         # This makes sorting by time work as expected.
-        def reformat(timestr):
+        def reformat_times(timestr):
             result = timestr
             if isinstance(result, str) and len(result) == 7:
                 result = '0' + result
             return result
 
         st[['arrival_time', 'departure_time']] =\
-          st[['arrival_time', 'departure_time']].applymap(reformat)
+          st[['arrival_time', 'departure_time']].applymap(reformat_times)
         self.stop_times = st
-
-        self.shapes = pd.read_csv(path + 'shapes.txt', dtype={'shape_id': str})
         
         # Note that at least one of calendar.txt or calendar_dates.txt is
         # required by the GTFS.
@@ -87,6 +88,8 @@ class Feed(object):
             self.calendar_dates = None
             self.calendar_dates_g = None
         
+        self.shapes = pd.read_csv(path + 'shapes.txt', dtype={'shape_id': str})
+
         if zipped:
             # Remove extracted directory
             shutil.rmtree(path)
@@ -212,7 +215,7 @@ class Feed(object):
             lons = group['shape_pt_lon'].values
             lats = group['shape_pt_lat'].values
             xys = [utm.from_latlon(lat, lon)[:2] 
-              for lat, lon in izip(lats, lons)]
+              for lat, lon in zip(lats, lons)]
             linestring_by_shape[shape] = LineString(xys)
         return linestring_by_shape
 
@@ -1041,7 +1044,7 @@ class Feed(object):
             end = pd.to_datetime(date_str + ' ' +\
               utils.timestr_mod_24(end_time))
 
-            for name, f in series_by_name.iteritems():
+            for name, f in series_by_name.items():
                 if start == end:
                     criterion = f.index == start
                     num_bins = 1
@@ -1157,7 +1160,7 @@ class Feed(object):
         # Stops time series
         sts = self.get_stops_time_series(dates)
         sts = utils.downsample_stops_time_series(sts, freq=freq)
-        for name, f in sts.iteritems():
+        for name, f in sts.items():
             # Remove date from timestamps
             g = f.copy()
             g.index = [d.time() for d in g.index.to_datetime()]
@@ -1176,7 +1179,7 @@ class Feed(object):
         # Routes time series
         rts = self.get_routes_time_series(trips_stats, dates)
         rts = utils.downsample_routes_time_series(rts, freq=freq)
-        for name, f in rts.iteritems():
+        for name, f in rts.items():
             # Remove date from timestamps
             g = f.copy()
             g.index = [d.time() for d in g.index.to_datetime()]
