@@ -1,4 +1,3 @@
-from __future__ import division
 import unittest
 
 import pandas as pd 
@@ -96,7 +95,8 @@ class TestFeed(unittest.TestCase):
         # Should be a dictionary
         self.assertIsInstance(linestring_by_shape, dict)
         # The first element should be a Shapely linestring
-        self.assertIsInstance(linestring_by_shape.values()[0], LineString)
+        self.assertIsInstance(list(linestring_by_shape.values())[0], 
+          LineString)
         # Should contain the correct number of shapes
         self.assertEqual(len(linestring_by_shape), 
           feed.shapes.groupby('shape_id').first().shape[0])
